@@ -14,11 +14,11 @@ Date::Advent - Calculate the Sundays of Advent
 
 =head1 VERSION
 
-Version 1.20161221
+Version 1.20161222
 
 =cut
 
-our $VERSION = '1.20161221';
+our $VERSION = '1.20161222';
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ As Advent is the beginning of the Christian liturgical calendar, this usually re
 
 The development of this module is hosted on GitHub -- L<https://github.com/marmanold/Date-Advent> -- and tested via TravisCI.
 
-=for html <a href='https://travis-ci.org/marmanold/Date-Advent'><img src='https://travis-ci.org/marmanold/Date-Advent.svg?branch=master'></a>
+=for html <a href='https://travis-ci.org/marmanold/Date-Advent'><img src='https://travis-ci.org/marmanold/Date-Advent.svg?branch=master' /></a>
 
 =for html <a href='https://coveralls.io/github/marmanold/Date-Advent?branch=master'><img src='https://coveralls.io/repos/github/marmanold/Date-Advent/badge.svg?branch=master' alt='Coverage Status' /></a>
 
@@ -163,9 +163,6 @@ Michael Wayne Arnold, C<< <marmanold at cpan.org> >>
 Please report any bugs or feature requests to C<bug-date-advent at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Date-Advent>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -198,6 +195,7 @@ L<http://search.cpan.org/dist/Date-Advent/>
 
 =head1 ACKNOWLEDGEMENTS
 
+Many thanks to my beautiful wife, Jennifer, and my amazing daughter, Rosemary.  But, above all, SOLI DEO GLORIA!
 
 =head1 LICENSE AND COPYRIGHT
 
